summaryrefslogtreecommitdiffstats
path: root/external
diff options
context:
space:
mode:
authorDavid Tardon <dtardon@redhat.com>2014-05-24 14:21:21 +0200
committerDavid Tardon <dtardon@redhat.com>2014-05-26 18:49:04 +0200
commit48c9d7ac7ccdad27067efe0d168e96ff48372631 (patch)
tree82b808b8c597046ed507aa6e2badd21090090190 /external
parentcoverity#1158084 Unchecked dynamic_cast (diff)
downloadcore-48c9d7ac7ccdad27067efe0d168e96ff48372631.tar.gz
core-48c9d7ac7ccdad27067efe0d168e96ff48372631.zip
rebase all import libs
Change-Id: I9e1fc613816c943f4fb1033185e34e3acf317f1d
Diffstat (limited to 'external')
-rw-r--r--external/libabw/ExternalProject_libabw.mk7
-rw-r--r--external/libcdr/ExternalProject_libcdr.mk9
-rw-r--r--external/libebook/0001-blind-attempt-to-workaround-MSVC-bug.patch87
-rw-r--r--external/libebook/ExternalProject_libebook.mk10
-rw-r--r--external/libebook/UnpackedTarball_libebook.mk4
-rw-r--r--external/libetonyek/ExternalProject_libetonyek.mk5
-rw-r--r--external/libfreehand/ExternalProject_libfreehand.mk9
-rw-r--r--external/libmspub/ExternalProject_libmspub.mk9
-rw-r--r--external/libmwaw/0001-librevenge-stream-is-optional-don-t-depend-on-it.patch293
-rw-r--r--external/libmwaw/0001-std-isfinite-is-C-11.patch43
-rw-r--r--external/libmwaw/0001-use-correct-type.patch52
-rw-r--r--external/libmwaw/0001-values4003-apparently-contains-22-patterns-not-28.patch29
-rw-r--r--external/libmwaw/0002-librevenge-stream-is-optional-don-t-depend-on-it.patch54
-rw-r--r--external/libmwaw/ExternalProject_libmwaw.mk7
-rw-r--r--external/libmwaw/UnpackedTarball_libmwaw.mk5
-rw-r--r--external/libodfgen/0001-properly-export-API-symbols.patch67
-rw-r--r--external/libodfgen/ExternalPackage_libodfgen.mk6
-rw-r--r--external/libodfgen/ExternalProject_libodfgen.mk4
-rw-r--r--external/libodfgen/Library_odfgen.mk10
-rw-r--r--external/librevenge/0001-nested-iterator-classes-need-to-be-exported-too.patch53
-rw-r--r--external/librevenge/UnpackedTarball_librevenge.mk1
-rw-r--r--external/libvisio/0001-fdo-70480-do-not-crash-reading-malformed-zip.patch26
-rw-r--r--external/libvisio/ExternalProject_libvisio.mk9
-rw-r--r--external/libvisio/UnpackedTarball_libvisio.mk6
-rw-r--r--external/libwpd/ExternalProject_libwpd.mk15
-rw-r--r--external/libwpg/ExternalProject_libwpg.mk7
-rw-r--r--external/libwpg/UnpackedTarball_libwpg.mk7
-rw-r--r--external/libwps/ExternalProject_libwps.mk8
28 files changed, 600 insertions, 242 deletions
diff --git a/external/libabw/ExternalProject_libabw.mk b/external/libabw/ExternalProject_libabw.mk
index 1bcb33d763d2..63d4e52136fa 100644
--- a/external/libabw/ExternalProject_libabw.mk
+++ b/external/libabw/ExternalProject_libabw.mk
@@ -18,7 +18,7 @@ $(eval $(call gb_ExternalProject_register_targets,libabw,\
$(eval $(call gb_ExternalProject_use_externals,libabw,\
boost_headers \
libxml2 \
- wpd \
+ revenge \
zlib \
))
@@ -33,13 +33,12 @@ $(call gb_ExternalProject_get_state_target,libabw,build) :
--disable-tools \
--disable-debug \
--disable-werror \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
CXXFLAGS="$(if $(SYSTEM_BOOST),$(BOOST_CPPFLAGS),\
-I$(call gb_UnpackedTarball_get_dir,boost) -I$(BUILDDIR)/config_$(gb_Side)) \
$(if $(SYSTEM_LIBXML),,-I$(call gb_UnpackedTarball_get_dir,xml2)/include)" \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && (cd $(EXTERNAL_WORKDIR)/src/lib && \
- $(if $(VERBOSE)$(verbose),V=1) \
- $(MAKE)) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libcdr/ExternalProject_libcdr.mk b/external/libcdr/ExternalProject_libcdr.mk
index d96b0b227ed2..174de182ad60 100644
--- a/external/libcdr/ExternalProject_libcdr.mk
+++ b/external/libcdr/ExternalProject_libcdr.mk
@@ -19,8 +19,7 @@ $(eval $(call gb_ExternalProject_use_externals,libcdr,\
boost_headers \
icu \
lcms2 \
- wpd \
- wpg \
+ revenge \
zlib \
))
@@ -32,14 +31,14 @@ $(call gb_ExternalProject_get_state_target,libcdr,build) :
--enable-static \
--disable-shared \
--without-docs \
+ --disable-tools \
--disable-debug \
--disable-werror \
--disable-weffc \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
CXXFLAGS="$(if $(SYSTEM_BOOST),$(BOOST_CPPFLAGS),-I$(call gb_UnpackedTarball_get_dir,boost) -I$(BUILDDIR)/config_$(gb_Side))" \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && (cd $(EXTERNAL_WORKDIR)/src/lib && \
- $(if $(VERBOSE)$(verbose),V=1) \
- $(MAKE)) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libebook/0001-blind-attempt-to-workaround-MSVC-bug.patch b/external/libebook/0001-blind-attempt-to-workaround-MSVC-bug.patch
new file mode 100644
index 000000000000..2ecedf3dd801
--- /dev/null
+++ b/external/libebook/0001-blind-attempt-to-workaround-MSVC-bug.patch
@@ -0,0 +1,87 @@
+From e9362c25b772c2cfb657b1234d8b636669a1b01b Mon Sep 17 00:00:00 2001
+From: David Tardon <dtardon@redhat.com>
+Date: Mon, 26 May 2014 16:33:00 +0200
+Subject: [PATCH] blind attempt to workaround MSVC bug
+
+http://msdn.microsoft.com/en-us/library/27zksbks.aspx
+---
+ src/lib/EBOOKDocument.cpp | 49 ++++++++++++++++++++++++++++-------------------
+ 1 file changed, 29 insertions(+), 20 deletions(-)
+
+diff --git a/src/lib/EBOOKDocument.cpp b/src/lib/EBOOKDocument.cpp
+index ea1a223..5b8e7ec 100644
+--- a/src/lib/EBOOKDocument.cpp
++++ b/src/lib/EBOOKDocument.cpp
+@@ -173,6 +173,15 @@ catch (...)
+ return EBOOKDocument::TYPE_UNKNOWN;
+ }
+
++extern "C"
++{
++
++ void detectInternalSubset(void *const ctx, const xmlChar *const name, const xmlChar *, const xmlChar *);
++ void detectExternalSubset(void *const ctx, const xmlChar *const name, const xmlChar *, const xmlChar *);
++ void detectStartElement(void *const ctx, const xmlChar *const name, const xmlChar **);
++
++}
++
+ struct HTMLContext
+ {
+ xmlSAXHandler handler;
+@@ -196,26 +205,6 @@ void detectHTMLContent(void *const ctx, const xmlChar *const name)
+ context->html = EBOOKHTMLToken::html == getHTMLTokenId(char_cast(name));
+ }
+
+-extern "C"
+-{
+-
+- void detectInternalSubset(void *const ctx, const xmlChar *const name, const xmlChar *, const xmlChar *)
+- {
+- detectHTMLContent(ctx, name);
+- }
+-
+- void detectExternalSubset(void *const ctx, const xmlChar *const name, const xmlChar *, const xmlChar *)
+- {
+- detectHTMLContent(ctx, name);
+- }
+-
+- void detectStartElement(void *const ctx, const xmlChar *const name, const xmlChar **)
+- {
+- detectHTMLContent(ctx, name);
+- }
+-
+-}
+-
+ HTMLContext::HTMLContext()
+ : handler()
+ , detected(false)
+@@ -250,6 +239,26 @@ catch (...)
+ return false;
+ }
+
++extern "C"
++{
++
++ void detectInternalSubset(void *const ctx, const xmlChar *const name, const xmlChar *, const xmlChar *)
++ {
++ detectHTMLContent(ctx, name);
++ }
++
++ void detectExternalSubset(void *const ctx, const xmlChar *const name, const xmlChar *, const xmlChar *)
++ {
++ detectHTMLContent(ctx, name);
++ }
++
++ void detectStartElement(void *const ctx, const xmlChar *const name, const xmlChar **)
++ {
++ detectHTMLContent(ctx, name);
++ }
++
++}
++
+ template<class Parser>
+ bool probe(const RVNGInputStreamPtr_t &input, const EBOOKDocument::Type type, EBOOKDocument::Type *const typeOut, EBOOKDocument::Confidence &confidence) try
+ {
+--
+1.9.0
+
diff --git a/external/libebook/ExternalProject_libebook.mk b/external/libebook/ExternalProject_libebook.mk
index b4e2bd6a8378..785aeb714f14 100644
--- a/external/libebook/ExternalProject_libebook.mk
+++ b/external/libebook/ExternalProject_libebook.mk
@@ -19,10 +19,11 @@ $(eval $(call gb_ExternalProject_use_externals,libebook,\
boost_headers \
icu \
libxml2 \
- wpd \
+ revenge \
zlib \
))
+# TODO: remove the generators/stream empty vars on libe-book update
$(call gb_ExternalProject_get_state_target,libebook,build) :
$(call gb_ExternalProject_run,build,\
export PKG_CONFIG="" \
@@ -31,15 +32,18 @@ $(call gb_ExternalProject_get_state_target,libebook,build) :
--enable-static \
--disable-shared \
--without-docs \
+ --without-tools \
+ --disable-tests \
$(if $(filter TRUE,$(ENABLE_DEBUG)),--enable-debug,--disable-debug) \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
--disable-werror \
--disable-weffc \
CXXFLAGS="$(if $(SYSTEM_BOOST),$(BOOST_CPPFLAGS),-I$(call gb_UnpackedTarball_get_dir,boost) -I$(BUILDDIR)/config_$(gb_Side))" \
XML_CFLAGS="$(if $(SYSTEM_LIBXML),$(LIBXML_CFLAGS),-I$(call gb_UnpackedTarball_get_dir,xml2)/include)" \
XML_LIBS="$(LIBXML_LIBS)" \
+ REVENGE_GENERATORS_CFLAGS=' ' REVENGE_GENERATORS_LIBS=' ' REVENGE_STREAM_CFLAGS=' ' REVENGE_STREAM_LIBS=' ' \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && cd src/lib \
- && $(MAKE) $(if $(VERBOSE)$(verbose),V=1) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libebook/UnpackedTarball_libebook.mk b/external/libebook/UnpackedTarball_libebook.mk
index 7dfee2c7550d..bcc098a6643e 100644
--- a/external/libebook/UnpackedTarball_libebook.mk
+++ b/external/libebook/UnpackedTarball_libebook.mk
@@ -13,4 +13,8 @@ $(eval $(call gb_UnpackedTarball_set_tarball,libebook,$(EBOOK_TARBALL)))
$(eval $(call gb_UnpackedTarball_set_patchlevel,libebook,1))
+$(eval $(call gb_UnpackedTarball_add_patches,libebook,\
+ external/libebook/0001-blind-attempt-to-workaround-MSVC-bug.patch \
+))
+
# vim: set noet sw=4 ts=4:
diff --git a/external/libetonyek/ExternalProject_libetonyek.mk b/external/libetonyek/ExternalProject_libetonyek.mk
index 11082822ec2a..ddf139420e78 100644
--- a/external/libetonyek/ExternalProject_libetonyek.mk
+++ b/external/libetonyek/ExternalProject_libetonyek.mk
@@ -18,7 +18,7 @@ $(eval $(call gb_ExternalProject_register_targets,libetonyek,\
$(eval $(call gb_ExternalProject_use_externals,libetonyek,\
boost_headers \
libxml2 \
- wpd \
+ revenge \
zlib \
))
@@ -34,11 +34,12 @@ $(call gb_ExternalProject_get_state_target,libetonyek,build) :
--disable-werror \
--disable-weffc \
--without-tools \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
BOOST_CFLAGS="$(if $(SYSTEM_BOOST),$(BOOST_CPPFLAGS),-I$(call gb_UnpackedTarball_get_dir,boost) -I$(BUILDDIR)/config_$(gb_Side))" \
XML_CFLAGS="$(if $(SYSTEM_LIBXML),$(LIBXML_CFLAGS),-I$(call gb_UnpackedTarball_get_dir,xml2)/include)" \
XML_LIBS="$(LIBXML_LIBS)" \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && $(MAKE) $(if $(VERBOSE)$(verbose),V=1) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libfreehand/ExternalProject_libfreehand.mk b/external/libfreehand/ExternalProject_libfreehand.mk
index 068d88667867..39380e9bc01a 100644
--- a/external/libfreehand/ExternalProject_libfreehand.mk
+++ b/external/libfreehand/ExternalProject_libfreehand.mk
@@ -16,8 +16,7 @@ $(eval $(call gb_ExternalProject_register_targets,libfreehand,\
))
$(eval $(call gb_ExternalProject_use_externals,libfreehand,\
- wpd \
- wpg \
+ revenge \
zlib \
))
@@ -29,13 +28,13 @@ $(call gb_ExternalProject_get_state_target,libfreehand,build) :
--enable-static \
--disable-shared \
--without-docs \
+ --disable-tools \
--disable-debug \
--disable-werror \
--disable-weffc \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && (cd $(EXTERNAL_WORKDIR)/src/lib && \
- $(if $(VERBOSE)$(verbose),V=1) \
- $(MAKE)) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libmspub/ExternalProject_libmspub.mk b/external/libmspub/ExternalProject_libmspub.mk
index a9edc009e908..8cbf9a6c42eb 100644
--- a/external/libmspub/ExternalProject_libmspub.mk
+++ b/external/libmspub/ExternalProject_libmspub.mk
@@ -18,8 +18,7 @@ $(eval $(call gb_ExternalProject_register_targets,libmspub,\
$(eval $(call gb_ExternalProject_use_externals,libmspub,\
boost_headers \
icu \
- wpd \
- wpg \
+ revenge \
))
$(call gb_ExternalProject_get_state_target,libmspub,build) :
@@ -30,14 +29,14 @@ $(call gb_ExternalProject_get_state_target,libmspub,build) :
--enable-static \
--disable-shared \
--without-docs \
+ --disable-tools \
--disable-debug \
--disable-werror \
--disable-weffc \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
CXXFLAGS="$(if $(SYSTEM_BOOST),$(BOOST_CPPFLAGS),-I$(call gb_UnpackedTarball_get_dir,boost) -I$(BUILDDIR)/config_$(gb_Side))" \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && (cd $(EXTERNAL_WORKDIR)/src/lib && \
- $(if $(VERBOSE)$(verbose),V=1) \
- $(MAKE)) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libmwaw/0001-librevenge-stream-is-optional-don-t-depend-on-it.patch b/external/libmwaw/0001-librevenge-stream-is-optional-don-t-depend-on-it.patch
new file mode 100644
index 000000000000..2b42f90ef14d
--- /dev/null
+++ b/external/libmwaw/0001-librevenge-stream-is-optional-don-t-depend-on-it.patch
@@ -0,0 +1,293 @@
+From 7b7cf183a7ad454706aa0f1657c851c578ec476e Mon Sep 17 00:00:00 2001
+From: David Tardon <dtardon@redhat.com>
+Date: Sun, 25 May 2014 15:51:54 +0200
+Subject: [PATCH] librevenge-stream is optional: don't depend on it
+
+---
+ src/lib/MWAWStringStream.cxx | 153 +++++++++++++++++++++++++++++++++++++++++++
+ src/lib/MWAWStringStream.hxx | 50 ++++++++++++++
+ src/lib/Makefile.am | 2 +
+ src/lib/WingzParser.cxx | 3 +-
+ 4 files changed, 207 insertions(+), 1 deletion(-)
+ create mode 100644 src/lib/MWAWStringStream.cxx
+ create mode 100644 src/lib/MWAWStringStream.hxx
+
+diff --git a/src/lib/MWAWStringStream.cxx b/src/lib/MWAWStringStream.cxx
+new file mode 100644
+index 0000000..efea071
+--- /dev/null
++++ b/src/lib/MWAWStringStream.cxx
+@@ -0,0 +1,153 @@
++/* -*- Mode: C++; c-default-style: "k&r"; indent-tabs-mode: nil; tab-width: 2; c-basic-offset: 2 -*- */
++
++/* libmwaw
++* Version: MPL 2.0 / LGPLv2+
++*
++* The contents of this file are subject to the Mozilla Public License Version
++* 2.0 (the "License"); you may not use this file except in compliance with
++* the License or as specified alternatively below. You may obtain a copy of
++* the License at http://www.mozilla.org/MPL/
++*
++* Software distributed under the License is distributed on an "AS IS" basis,
++* WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
++* for the specific language governing rights and limitations under the
++* License.
++*
++* Alternatively, the contents of this file may be used under the terms of
++* the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
++* in which case the provisions of the LGPLv2+ are applicable
++* instead of those above.
++*/
++
++#include <cstring>
++#include <vector>
++
++#include <librevenge-stream/librevenge-stream.h>
++
++#include "MWAWStringStream.hxx"
++
++class MWAWStringStreamPrivate
++{
++public:
++ MWAWStringStreamPrivate(const unsigned char *data, unsigned dataSize);
++ ~MWAWStringStreamPrivate();
++ std::vector<unsigned char> buffer;
++ long offset;
++private:
++ MWAWStringStreamPrivate(const MWAWStringStreamPrivate &);
++ MWAWStringStreamPrivate &operator=(const MWAWStringStreamPrivate &);
++};
++
++MWAWStringStreamPrivate::MWAWStringStreamPrivate(const unsigned char *data, unsigned dataSize) :
++ buffer(dataSize),
++ offset(0)
++{
++ std::memcpy(&buffer[0], data, dataSize);
++}
++
++MWAWStringStreamPrivate::~MWAWStringStreamPrivate()
++{
++}
++
++MWAWStringStream::MWAWStringStream(const unsigned char *data, const unsigned int dataSize) :
++ librevenge::RVNGInputStream(),
++ d(new MWAWStringStreamPrivate(data, dataSize))
++{
++}
++
++MWAWStringStream::~MWAWStringStream()
++{
++ delete d;
++}
++
++const unsigned char *MWAWStringStream::read(unsigned long numBytes, unsigned long &numBytesRead)
++{
++ numBytesRead = 0;
++
++ if (numBytes == 0)
++ return 0;
++
++ long numBytesToRead;
++
++ if ((unsigned long)d->offset+numBytes < d->buffer.size())
++ numBytesToRead = (long) numBytes;
++ else
++ numBytesToRead = (long) d->buffer.size() - d->offset;
++
++ numBytesRead = (unsigned long) numBytesToRead; // about as paranoid as we can be..
++
++ if (numBytesToRead == 0)
++ return 0;
++
++ long oldOffset = d->offset;
++ d->offset += numBytesToRead;
++
++ return &d->buffer[size_t(oldOffset)];
++
++}
++
++long MWAWStringStream::tell()
++{
++ return d->offset;
++}
++
++int MWAWStringStream::seek(long offset, librevenge::RVNG_SEEK_TYPE seekType)
++{
++ if (seekType == librevenge::RVNG_SEEK_CUR)
++ d->offset += offset;
++ else if (seekType == librevenge::RVNG_SEEK_SET)
++ d->offset = offset;
++ else if (seekType == librevenge::RVNG_SEEK_END)
++ d->offset += d->buffer.size();
++
++ if (d->offset < 0) {
++ d->offset = 0;
++ return 1;
++ }
++ if ((long)d->offset > (long)d->buffer.size()) {
++ d->offset = (long) d->buffer.size();
++ return 1;
++ }
++
++ return 0;
++}
++
++bool MWAWStringStream::isEnd()
++{
++ if ((long)d->offset >= (long)d->buffer.size())
++ return true;
++
++ return false;
++}
++
++bool MWAWStringStream::isStructured()
++{
++ return false;
++}
++
++unsigned MWAWStringStream::subStreamCount()
++{
++ return 0;
++}
++
++const char *MWAWStringStream::subStreamName(unsigned)
++{
++ return 0;
++}
++
++bool MWAWStringStream::existsSubStream(const char *)
++{
++ return false;
++}
++
++librevenge::RVNGInputStream *MWAWStringStream::getSubStreamById(unsigned)
++{
++ return 0;
++}
++
++librevenge::RVNGInputStream *MWAWStringStream::getSubStreamByName(const char *)
++{
++ return 0;
++}
++
++// vim: set filetype=cpp tabstop=2 shiftwidth=2 cindent autoindent smartindent noexpandtab:
+diff --git a/src/lib/MWAWStringStream.hxx b/src/lib/MWAWStringStream.hxx
+new file mode 100644
+index 0000000..9a6aa02
+--- /dev/null
++++ b/src/lib/MWAWStringStream.hxx
+@@ -0,0 +1,50 @@
++/* -*- Mode: C++; c-default-style: "k&r"; indent-tabs-mode: nil; tab-width: 2; c-basic-offset: 2 -*- */
++
++/* libmwaw
++* Version: MPL 2.0 / LGPLv2+
++*
++* The contents of this file are subject to the Mozilla Public License Version
++* 2.0 (the "License"); you may not use this file except in compliance with
++* the License or as specified alternatively below. You may obtain a copy of
++* the License at http://www.mozilla.org/MPL/
++*
++* Software distributed under the License is distributed on an "AS IS" basis,
++* WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
++* for the specific language governing rights and limitations under the
++* License.
++*
++* Alternatively, the contents of this file may be used under the terms of
++* the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
++* in which case the provisions of the LGPLv2+ are applicable
++* instead of those above.
++*/
++
++#include <librevenge-stream/librevenge-stream.h>
++
++class MWAWStringStreamPrivate;
++
++class MWAWStringStream: public librevenge::RVNGInputStream
++{
++public:
++ MWAWStringStream(const unsigned char *data, const unsigned int dataSize);
++ ~MWAWStringStream();
++
++ const unsigned char *read(unsigned long numBytes, unsigned long &numBytesRead);
++ long tell();
++ int seek(long offset, librevenge::RVNG_SEEK_TYPE seekType);
++ bool isEnd();
++
++ bool isStructured();
++ unsigned subStreamCount();
++ const char *subStreamName(unsigned);
++ bool existsSubStream(const char *name);
++ librevenge::RVNGInputStream *getSubStreamByName(const char *name);
++ librevenge::RVNGInputStream *getSubStreamById(unsigned);
++
++private:
++ MWAWStringStreamPrivate *d;
++ MWAWStringStream(const MWAWStringStream &); // copy is not allowed
++ MWAWStringStream &operator=(const MWAWStringStream &); // assignment is not allowed
++};
++
++// vim: set filetype=cpp tabstop=2 shiftwidth=2 cindent autoindent smartindent noexpandtab:
+diff --git a/src/lib/Makefile.in b/src/lib/Makefile.in
+index eb17bad..f7934b4 100644
+--- a/src/lib/Makefile.in
++++ b/src/lib/Makefile.in
+@@ -162,12 +162,12 @@ am_libmwaw_@MWAW_MAJOR_VERSION@_@MWAW_MI
+ MWAWPrinter.lo MWAWPropertyHandler.lo MWAWRSRCParser.lo \
+ MWAWSection.lo MWAWSpreadsheetDecoder.lo \
+ MWAWSpreadsheetEncoder.lo MWAWSpreadsheetListener.lo \
+- MWAWSubDocument.lo MWAWTable.lo MWAWTextListener.lo \
+- NisusWrtGraph.lo NisusWrtParser.lo NisusWrtStruct.lo \
+- NisusWrtText.lo RagTimeParser.lo RagTimeSpreadsheet.lo \
+- RagTimeText.lo SuperPaintParser.lo TeachTxtParser.lo \
+- WingzParser.lo WriteNowParser.lo WriteNowText.lo \
+- WriterPlsParser.lo ZWrtParser.lo ZWrtText.lo
++ MWAWStringStream.lo MWAWSubDocument.lo MWAWTable.lo \
++ MWAWTextListener.lo NisusWrtGraph.lo NisusWrtParser.lo \
++ NisusWrtStruct.lo NisusWrtText.lo RagTimeParser.lo \
++ RagTimeSpreadsheet.lo RagTimeText.lo SuperPaintParser.lo \
++ TeachTxtParser.lo WingzParser.lo WriteNowParser.lo \
++ WriteNowText.lo WriterPlsParser.lo ZWrtParser.lo ZWrtText.lo
+ libmwaw_@MWAW_MAJOR_VERSION@_@MWAW_MINOR_VERSION@_la_OBJECTS = $(am_libmwaw_@MWAW_MAJOR_VERSION@_@MWAW_MINOR_VERSION@_la_OBJECTS)
+ AM_V_lt = $(am__v_lt_@AM_V@)
+ am__v_lt_ = $(am__v_lt_@AM_DEFAULT_V@)
+@@ -610,6 +610,8 @@ libmwaw_@MWAW_MAJOR_VERSION@_@MWAW_MINOR
+ MWAWSpreadsheetEncoder.hxx \
+ MWAWSpreadsheetListener.cxx \
+ MWAWSpreadsheetListener.hxx \
++ MWAWStringStream.cxx \
++ MWAWStringStream.hxx \
+ MWAWSubDocument.cxx \
+ MWAWSubDocument.hxx \
+ MWAWTable.cxx \
+@@ -812,6 +814,7 @@ distclean-compile:
+ @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/MWAWSpreadsheetDecoder.Plo@am__quote@
+ @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/MWAWSpreadsheetEncoder.Plo@am__quote@
+ @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/MWAWSpreadsheetListener.Plo@am__quote@
++@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/MWAWStringStream.Plo@am__quote@
+ @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/MWAWSubDocument.Plo@am__quote@
+ @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/MWAWTable.Plo@am__quote@
+ @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/MWAWTextListener.Plo@am__quote@
+diff --git a/src/lib/WingzParser.cxx b/src/lib/WingzParser.cxx
+index 4813816..93dde7d 100644
+--- a/src/lib/WingzParser.cxx
++++ b/src/lib/WingzParser.cxx
+@@ -49,6 +49,7 @@
+ #include "MWAWPictMac.hxx"
+ #include "MWAWPrinter.hxx"
+ #include "MWAWSpreadsheetListener.hxx"
++#include "MWAWStringStream.hxx"
+ #include "MWAWSubDocument.hxx"
+
+ #include "WingzParser.hxx"
+@@ -2496,7 +2497,7 @@ bool WingzParser::decodeEncrypted()
+
+ // finally replace the actual input with a new input
+ shared_ptr<librevenge::RVNGInputStream> newInput
+- (new librevenge::RVNGStringStream(buffer, (unsigned int)length));
++ (new MWAWStringStream(buffer, (unsigned int)length));
+ delete [] buffer;
+ getParserState()->m_input.reset(new MWAWInputStream(newInput, false));
+ return true;
+--
+1.9.0
+
diff --git a/external/libmwaw/0001-std-isfinite-is-C-11.patch b/external/libmwaw/0001-std-isfinite-is-C-11.patch
deleted file mode 100644
index 73fde5ae0387..000000000000
--- a/external/libmwaw/0001-std-isfinite-is-C-11.patch
+++ /dev/null
@@ -1,43 +0,0 @@
-From 5da59d9aa9298136d447e4014aef207f00cdc82b Mon Sep 17 00:00:00 2001
-From: David Tardon <dtardon@redhat.com>
-Date: Sun, 3 Nov 2013 12:26:26 +0100
-Subject: [PATCH] std::isfinite is C++11
-
----
- configure.ac | 10 ++++++++++
- src/lib/CWDbaseContent.cxx | 5 +++--
- 2 files changed, 13 insertions(+), 2 deletions(-)
-
-diff --git a/src/lib/CWDbaseContent.cxx b/src/lib/CWDbaseContent.cxx
-index f27148d..7198103 100644
---- a/src/lib/CWDbaseContent.cxx
-+++ b/src/lib/CWDbaseContent.cxx
-@@ -33,7 +33,6 @@
-
- #include <time.h>
-
--#include <cmath>
- #include <cstring>
- #include <ctime>
- #include <iomanip>
-@@ -41,6 +40,8 @@
- #include <set>
- #include <sstream>
-
-+#include <boost/math/special_functions/fpclassify.hpp>
-+
- #include <libwpd/libwpd.h>
-
- #include "MWAWContentListener.hxx"
-@@ -969,7 +970,7 @@ void CWDbaseContent::send(double val, CWStyleManager::CellFormat const &format)
- if (type>=10&&type<=11) type += 4;
- else if (type>=14) type=16;
- }
-- if (type <= 0 || type >=16 || type==10 || type==11 || !std::isfinite(val)) {
-+ if (type <= 0 || type >=16 || type==10 || type==11 || !boost::math::isfinite(val)) {
- s << val;
- listener->insertUnicodeString(s.str().c_str());
- return;
---
-1.8.3.1
-
diff --git a/external/libmwaw/0001-use-correct-type.patch b/external/libmwaw/0001-use-correct-type.patch
deleted file mode 100644
index 7a6ef2dc4689..000000000000
--- a/external/libmwaw/0001-use-correct-type.patch
+++ /dev/null
@@ -1,52 +0,0 @@
-From cde8d7c47cdea327f8153ab72cde650f1b36f7f8 Mon Sep 17 00:00:00 2001
-From: David Tardon <dtardon@redhat.com>
-Date: Sun, 3 Nov 2013 12:59:29 +0100
-Subject: [PATCH] use correct type
-
----
- src/lib/HMWJGraph.cxx | 8 ++++----
- 1 file changed, 4 insertions(+), 4 deletions(-)
-
-diff --git a/src/lib/HMWJGraph.cxx b/src/lib/HMWJGraph.cxx
-index fca366c..dd83ace 100644
---- a/src/lib/HMWJGraph.cxx
-+++ b/src/lib/HMWJGraph.cxx
-@@ -2668,7 +2668,7 @@ bool HMWJGraph::sendGroup(HMWJGraphInternal::Group const &group, MWAWPosition po
- return true;
- }
-
-- std::multimap<long, int>::const_iterator fIt;
-+ std::map<long, int>::const_iterator fIt;
- int numFrames = int(m_state->m_framesList.size());
- for (size_t c=0; c<group.m_childsList.size(); ++c) {
- long fId=group.m_childsList[c];
-@@ -2690,7 +2690,7 @@ bool HMWJGraph::sendGroup(HMWJGraphInternal::Group const &group, MWAWPosition po
-
- bool HMWJGraph::canCreateGraphic(HMWJGraphInternal::Group const &group)
- {
-- std::multimap<long, int>::const_iterator fIt;
-+ std::map<long, int>::const_iterator fIt;
- int page = group.m_page;
- int numFrames = int(m_state->m_framesList.size());
- for (size_t c=0; c<group.m_childsList.size(); ++c) {
-@@ -2726,7 +2726,7 @@ void HMWJGraph::sendGroup(HMWJGraphInternal::Group const &group, MWAWGraphicList
- if (!listener) return;
- group.m_parsed=true;
- MWAWInputStreamPtr &input= m_parserState->m_input;
-- std::multimap<long, int>::const_iterator fIt;
-+ std::map<long, int>::const_iterator fIt;
- int numFrames = int(m_state->m_framesList.size());
- for (size_t c=0; c<group.m_childsList.size(); ++c) {
- long fId=group.m_childsList[c];
-@@ -2784,7 +2784,7 @@ void HMWJGraph::sendGroupChild(HMWJGraphInternal::Group const &group, MWAWPositi
- Box2f partialBdBox;
- MWAWPosition partialPos(pos);
- MWAWInputStreamPtr &input= m_parserState->m_input;
-- std::multimap<long, int>::const_iterator fIt;
-+ std::map<long, int>::const_iterator fIt;
- int numFrames = int(m_state->m_framesList.size());
- for (size_t c=0; c<numChilds; ++c) {
- long fId=group.m_childsList[c];
---
-1.8.3.1
-
diff --git a/external/libmwaw/0001-values4003-apparently-contains-22-patterns-not-28.patch b/external/libmwaw/0001-values4003-apparently-contains-22-patterns-not-28.patch
deleted file mode 100644
index c06de9483b25..000000000000
--- a/external/libmwaw/0001-values4003-apparently-contains-22-patterns-not-28.patch
+++ /dev/null
@@ -1,29 +0,0 @@
-From 83188cec2826a2bffdb3daf27702510c3e02edea Mon Sep 17 00:00:00 2001
-From: Stephan Bergmann <sbergman@redhat.com>
-Date: Thu, 24 Apr 2014 10:40:05 +0200
-Subject: [PATCH] values4003 apparently contains 22 patterns, not 28
-
-(cherry picked from commit c2ee6f30deb497dcf0ffa18a7ade603f398d889f)
-
-Conflicts:
- src/lib/MSKGraph.cxx
----
- src/lib/MSKGraph.cxx | 2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/src/lib/MSKGraph.cxx b/src/lib/MSKGraph.cxx
-index 7c1a9f6..f32d7c6 100644
---- a/src/lib/MSKGraph.cxx
-+++ b/src/lib/MSKGraph.cxx
-@@ -728,7 +728,7 @@ void State::initPatterns(int vers)
- 0x55ff, 0x55ff, 0x55ff, 0x55ff, 0x55ff, 0xeeff, 0x55ff, 0xbbff, 0x77ff, 0xddff, 0x77ff, 0xddff, 0x7fff, 0xf7ff, 0x7fff, 0xf7ff,
- 0x7fff, 0xffff, 0xf7ff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
- };
-- m_rsrcPatternsMap.insert(std::map<long, Patterns>::value_type(4003,Patterns(28, values4003)));
-+ m_rsrcPatternsMap.insert(std::map<long, Patterns>::value_type(4003,Patterns(22, values4003)));
- static uint16_t const (values4004[]) = {
- 0xf0f0, 0xf0f0, 0x0f0f, 0x0f0f, 0xcccc, 0x3333, 0xcccc, 0x3333, 0x3333, 0xcccc, 0x3333, 0xcccc
- };
---
-1.9.0
-
diff --git a/external/libmwaw/0002-librevenge-stream-is-optional-don-t-depend-on-it.patch b/external/libmwaw/0002-librevenge-stream-is-optional-don-t-depend-on-it.patch
new file mode 100644
index 000000000000..bd94338a766d
--- /dev/null
+++ b/external/libmwaw/0002-librevenge-stream-is-optional-don-t-depend-on-it.patch
@@ -0,0 +1,54 @@
+From ead2223f2d3d4742df84f37c6cea9c73b71257c5 Mon Sep 17 00:00:00 2001
+From: David Tardon <dtardon@redhat.com>
+Date: Sun, 25 May 2014 16:07:21 +0200
+Subject: [PATCH] librevenge-stream is optional: don't depend on it
+
+---
+ src/lib/MWAWInputStream.cxx | 9 +++++----
+ 1 file changed, 5 insertions(+), 4 deletions(-)
+
+diff --git a/src/lib/MWAWInputStream.cxx b/src/lib/MWAWInputStream.cxx
+index 91b713b..0d60f67 100644
+--- a/src/lib/MWAWInputStream.cxx
++++ b/src/lib/MWAWInputStream.cxx
+@@ -43,6 +43,7 @@
+ #include "MWAWDebug.hxx"
+
+ #include "MWAWInputStream.hxx"
++#include "MWAWStringStream.hxx"
+
+ MWAWInputStream::MWAWInputStream(shared_ptr<librevenge::RVNGInputStream> inp, bool inverted)
+ : m_stream(inp), m_streamSize(0), m_inverseRead(inverted), m_readLimit(-1), m_prevLimits(),
+@@ -517,7 +518,7 @@ bool MWAWInputStream::unBinHex()
+ MWAW_DEBUG_MSG(("MWAWInputStream::unBinHex: can not read the resource fork\n"));
+ }
+ else {
+- shared_ptr<librevenge::RVNGInputStream> rsrc(new librevenge::RVNGStringStream(data, (unsigned int)numBytesRead));
++ shared_ptr<librevenge::RVNGInputStream> rsrc(new MWAWStringStream(data, (unsigned int)numBytesRead));
+ m_resourceFork.reset(new MWAWInputStream(rsrc,false));
+ }
+ }
+@@ -532,7 +533,7 @@ bool MWAWInputStream::unBinHex()
+ MWAW_DEBUG_MSG(("MWAWInputStream::unBinHex: can not read the data fork\n"));
+ return false;
+ }
+- m_stream.reset(new librevenge::RVNGStringStream(data, (unsigned int)numBytesRead));
++ m_stream.reset(new MWAWStringStream(data, (unsigned int)numBytesRead));
+ }
+
+ return true;
+@@ -692,9 +693,9 @@ bool MWAWInputStream::unMacMIME(MWAWInputStream *inp,
+ return false;
+ }
+ if (wh==1)
+- dataInput.reset(new librevenge::RVNGStringStream(data, (unsigned int)numBytesRead));
++ dataInput.reset(new MWAWStringStream(data, (unsigned int)numBytesRead));
+ else if (wh==2)
+- rsrcInput.reset(new librevenge::RVNGStringStream(data, (unsigned int)numBytesRead));
++ rsrcInput.reset(new MWAWStringStream(data, (unsigned int)numBytesRead));
+ else { // the finder info
+ if (entrySize < 8) {
+ MWAW_DEBUG_MSG(("MWAWInputStream::unMacMIME: finder info size is odd\n"));
+--
+1.9.0
+
diff --git a/external/libmwaw/ExternalProject_libmwaw.mk b/external/libmwaw/ExternalProject_libmwaw.mk
index e8d837b60648..bbc69a75909b 100644
--- a/external/libmwaw/ExternalProject_libmwaw.mk
+++ b/external/libmwaw/ExternalProject_libmwaw.mk
@@ -17,8 +17,7 @@ $(eval $(call gb_ExternalProject_register_targets,libmwaw,\
$(eval $(call gb_ExternalProject_use_externals,libmwaw,\
boost_headers \
- wpd \
- wpg \
+ revenge \
))
$(call gb_ExternalProject_get_state_target,libmwaw,build) :
@@ -29,12 +28,14 @@ $(call gb_ExternalProject_get_state_target,libmwaw,build) :
--enable-static \
--disable-shared \
--without-docs \
+ --disable-tools \
+ --disable-zip \
$(if $(filter TRUE,$(ENABLE_DEBUG)),--enable-debug,--disable-debug) \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
--disable-werror \
CXXFLAGS="$(if $(SYSTEM_BOOST),$(BOOST_CPPFLAGS),-I$(call gb_UnpackedTarball_get_dir,boost) -I$(BUILDDIR)/config_$(gb_Side))" \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
&& (cd $(EXTERNAL_WORKDIR)/src/lib && \
- $(if $(VERBOSE)$(verbose),V=1) \
$(MAKE)) \
)
diff --git a/external/libmwaw/UnpackedTarball_libmwaw.mk b/external/libmwaw/UnpackedTarball_libmwaw.mk
index 44fa61f3d743..6f63f2832be0 100644
--- a/external/libmwaw/UnpackedTarball_libmwaw.mk
+++ b/external/libmwaw/UnpackedTarball_libmwaw.mk
@@ -14,9 +14,8 @@ $(eval $(call gb_UnpackedTarball_set_tarball,libmwaw,$(MWAW_TARBALL)))
$(eval $(call gb_UnpackedTarball_set_patchlevel,libmwaw,1))
$(eval $(call gb_UnpackedTarball_add_patches,libmwaw,\
- external/libmwaw/0001-std-isfinite-is-C-11.patch \
- external/libmwaw/0001-use-correct-type.patch \
- external/libmwaw/0001-values4003-apparently-contains-22-patterns-not-28.patch \
+ external/libmwaw/0001-librevenge-stream-is-optional-don-t-depend-on-it.patch \
+ external/libmwaw/0002-librevenge-stream-is-optional-don-t-depend-on-it.patch \
))
# vim: set noet sw=4 ts=4:
diff --git a/external/libodfgen/0001-properly-export-API-symbols.patch b/external/libodfgen/0001-properly-export-API-symbols.patch
index 3f488ebdc1d3..91799aa82007 100644
--- a/external/libodfgen/0001-properly-export-API-symbols.patch
+++ b/external/libodfgen/0001-properly-export-API-symbols.patch
@@ -21,14 +21,14 @@ index 79c387b..19e04e3 100644
+++ b/inc/libodfgen/OdfDocumentHandler.hxx
@@ -26,6 +26,8 @@
#define _ODFDOCUMENTHANDLER_HXX_
- #include <libwpd/libwpd.h>
+ #include <librevenge/librevenge.h>
+#include "libodfgen-api.hxx"
+
/** Type of ODF content a generator should produce.
*
* @sa OdgGenerator, OdpGenerator, OdtGenerator
-@@ -57,7 +59,7 @@ typedef bool (*OdfEmbeddedImage)(const WPXBinaryData &input, librev
+@@ -57,7 +59,7 @@ typedef bool (*OdfEmbeddedImage)(const librevenge::RVNGBinaryData &input, librev
* saved to a file, printed to the standard output, saved to a file
* inside a package, or whatever else.
*/
@@ -42,64 +42,85 @@ index f818e3e..24455d8 100644
diff --git a/inc/libodfgen/libodfgen-api.hxx b/inc/libodfgen/libodfgen-api.hxx
new file mode 100644
index 0000000..39ffd05
diff --git a/external/libodfgen/ExternalPackage_libodfgen.mk b/external/libodfgen/ExternalPackage_libodfgen.mk
index a0692eda1e36..5ae18399e494 100644
--- a/external/libodfgen/ExternalPackage_libodfgen.mk
+++ b/external/libodfgen/ExternalPackage_libodfgen.mk
@@ -12,11 +12,11 @@ $(eval $(call gb_ExternalPackage_ExternalPackage,libodfgen,libodfgen))
$(eval $(call gb_ExternalPackage_use_external_project,libodfgen,libodfgen))
ifeq ($(OS),MACOSX)
-$(eval $(call gb_ExternalPackage_add_file,libodfgen,$(LIBO_LIB_FOLDER)/libodfgen-0.0.0.dylib,src/.libs/libodfgen-0.0.dylib))
+$(eval $(call gb_ExternalPackage_add_file,libodfgen,$(LIBO_LIB_FOLDER)/libodfgen-0.1.1.dylib,src/.libs/libodfgen-0.1.dylib))
else ifeq ($(OS),WNT)
-$(eval $(call gb_ExternalPackage_add_file,libodfgen,$(LIBO_LIB_FOLDER)/libodfgen-0.0.dll,src/.libs/libodfgen-0.0.dll))
+$(eval $(call gb_ExternalPackage_add_file,libodfgen,$(LIBO_LIB_FOLDER)/libodfgen-0.1.dll,src/.libs/libodfgen-0.1.dll))
else ifeq ($(filter IOS ANDROID,$(OS)),)
-$(eval $(call gb_ExternalPackage_add_file,libodfgen,$(LIBO_LIB_FOLDER)/libodfgen-0.0.so.0,src/.libs/libodfgen-0.0.so.0.0.4))
+$(eval $(call gb_ExternalPackage_add_file,libodfgen,$(LIBO_LIB_FOLDER)/libodfgen-0.1.so.1,src/.libs/libodfgen-0.1.so.1.0.0))
endif
# vim: set noet sw=4 ts=4:
diff --git a/external/libodfgen/ExternalProject_libodfgen.mk b/external/libodfgen/ExternalProject_libodfgen.mk
index 263e60dfc7a3..8d88486f1d99 100644
--- a/external/libodfgen/ExternalProject_libodfgen.mk
+++ b/external/libodfgen/ExternalProject_libodfgen.mk
@@ -17,9 +17,7 @@ $(eval $(call gb_ExternalProject_register_targets,libodfgen,\
$(eval $(call gb_ExternalProject_use_externals,libodfgen,\
boost_headers \
- etonyek \
- wpd \
- wpg \
+ revenge \
))
$(call gb_ExternalProject_get_state_target,libodfgen,build) :
diff --git a/external/libodfgen/Library_odfgen.mk b/external/libodfgen/Library_odfgen.mk
index ce187354b001..dfdd5df648c7 100644
--- a/external/libodfgen/Library_odfgen.mk
+++ b/external/libodfgen/Library_odfgen.mk
@@ -13,9 +13,7 @@ $(eval $(call gb_Library_use_unpacked,odfgen,libodfgen))
$(eval $(call gb_Library_use_externals,odfgen,\
boost_headers \
- etonyek \
- wpd \
- wpg \
+ revenge \
))
$(eval $(call gb_Library_set_warnings_not_errors,odfgen))
@@ -34,15 +32,21 @@ $(eval $(call gb_Library_add_defs,odfgen,\
$(eval $(call gb_Library_add_generated_exception_objects,odfgen,\
UnpackedTarball/libodfgen/src/DocumentElement \
+ UnpackedTarball/libodfgen/src/FilterInternal \
UnpackedTarball/libodfgen/src/FontStyle \
UnpackedTarball/libodfgen/src/GraphicFunctions \
+ UnpackedTarball/libodfgen/src/GraphicStyle \
UnpackedTarball/libodfgen/src/InternalHandler \
UnpackedTarball/libodfgen/src/ListStyle \
+ UnpackedTarball/libodfgen/src/OdcGenerator \
+ UnpackedTarball/libodfgen/src/OdfGenerator \
UnpackedTarball/libodfgen/src/OdgGenerator \
UnpackedTarball/libodfgen/src/OdpGenerator \
+ UnpackedTarball/libodfgen/src/OdsGenerator \
UnpackedTarball/libodfgen/src/OdtGenerator \
UnpackedTarball/libodfgen/src/PageSpan \
UnpackedTarball/libodfgen/src/SectionStyle \
+ UnpackedTarball/libodfgen/src/SheetStyle \
UnpackedTarball/libodfgen/src/TableStyle \
UnpackedTarball/libodfgen/src/TextRunStyle \
))
diff --git a/external/librevenge/0001-nested-iterator-classes-need-to-be-exported-too.patch b/external/librevenge/0001-nested-iterator-classes-need-to-be-exported-too.patch
new file mode 100644
index 000000000000..a6055f99e33a
--- /dev/null
+++ b/external/librevenge/0001-nested-iterator-classes-need-to-be-exported-too.patch
@@ -0,0 +1,53 @@
+From 03c0fe096ae6e71237d36b88f5f0aa0f62eb09d6 Mon Sep 17 00:00:00 2001
+From: David Tardon <dtardon@redhat.com>
+Date: Mon, 26 May 2014 14:47:57 +0200
+Subject: [PATCH] nested iterator classes need to be exported too
+
+---
+ inc/librevenge/RVNGPropertyList.h | 2 +-
+ inc/librevenge/RVNGPropertyListVector.h | 2 +-
+ inc/librevenge/RVNGString.h | 2 +-
+ 3 files changed, 3 insertions(+), 3 deletions(-)
+
+diff --git a/inc/librevenge/RVNGPropertyList.h b/inc/librevenge/RVNGPropertyList.h
+index c00af07..ac9c10d 100644
+--- a/inc/librevenge/RVNGPropertyList.h
++++ b/inc/librevenge/RVNGPropertyList.h
+@@ -60,7 +60,7 @@ public:
+
+ RVNGString getPropString() const;
+
+- class Iter
++ class REVENGE_API Iter
+ {
+ public:
+ Iter(const RVNGPropertyList &propList);
+diff --git a/inc/librevenge/RVNGPropertyListVector.h b/inc/librevenge/RVNGPropertyListVector.h
+index 850326e..d56f583 100644
+--- a/inc/librevenge/RVNGPropertyListVector.h
++++ b/inc/librevenge/RVNGPropertyListVector.h
+@@ -55,7 +55,7 @@ public:
+
+ RVNGString getPropString() const;
+
+- class Iter
++ class REVENGE_API Iter
+ {
+ public:
+ Iter(const RVNGPropertyListVector &vect);
+diff --git a/inc/librevenge/RVNGString.h b/inc/librevenge/RVNGString.h
+index cbea3bc..429170a 100644
+--- a/inc/librevenge/RVNGString.h
++++ b/inc/librevenge/RVNGString.h
+@@ -118,7 +118,7 @@ public:
+ return !operator<=(str);
+ }
+
+- class Iter
++ class REVENGE_API Iter
+ {
+ public:
+ Iter(const RVNGString &str);
+--
+1.9.0
+
diff --git a/external/librevenge/UnpackedTarball_librevenge.mk b/external/librevenge/UnpackedTarball_librevenge.mk
index 8311eabc7584..4fef6784621d 100644
--- a/external/librevenge/UnpackedTarball_librevenge.mk
+++ b/external/librevenge/UnpackedTarball_librevenge.mk
@@ -15,6 +15,7 @@ $(eval $(call gb_UnpackedTarball_set_patchlevel,librevenge,1))
$(eval $(call gb_UnpackedTarball_add_patches,librevenge,\
external/librevenge/0001-properly-export-API-symbols.patch \
+ external/librevenge/0001-nested-iterator-classes-need-to-be-exported-too.patch \
))
# vim: set noet sw=4 ts=4:
diff --git a/external/libvisio/0001-fdo-70480-do-not-crash-reading-malformed-zip.patch b/external/libvisio/0001-fdo-70480-do-not-crash-reading-malformed-zip.patch
deleted file mode 100644
index 6c7135f36ea4..000000000000
--- a/external/libvisio/0001-fdo-70480-do-not-crash-reading-malformed-zip.patch
+++ /dev/null
@@ -1,26 +0,0 @@
-From 410f564d9a728b983cf11ba9b3eadfc7d59c187c Mon Sep 17 00:00:00 2001
-From: David Tardon <dtardon@redhat.com>
-Date: Thu, 17 Oct 2013 10:35:34 +0200
-Subject: [PATCH] fdo#70480 do not crash reading malformed zip
-
-Change-Id: Ia37e8be5172a49669cb9f7271c5401ca88f39072
----
- src/lib/VSDZipStream.cpp | 2 ++
- 1 file changed, 2 insertions(+)
-
-diff --git a/src/lib/VSDZipStream.cpp b/src/lib/VSDZipStream.cpp
-index 3b3e08a..1c12d56 100644
---- a/src/lib/VSDZipStream.cpp
-+++ b/src/lib/VSDZipStream.cpp
-@@ -203,6 +203,8 @@ bool libvisio::VSDZipStreamImpl::isZipStream()
- return false;
- if (!readCentralDirectory(end))
- return false;
-+ if (m_cdir.empty())
-+ return false;
- CentralDirectoryEntry entry = m_cdir.begin()->second;
- m_input->seek(entry.offset, WPX_SEEK_SET);
- LocalFileHeader header;
---
-1.8.3.1
-
diff --git a/external/libvisio/ExternalProject_libvisio.mk b/external/libvisio/ExternalProject_libvisio.mk
index 597ea938b5e8..4ea2b238cf05 100644
--- a/external/libvisio/ExternalProject_libvisio.mk
+++ b/external/libvisio/ExternalProject_libvisio.mk
@@ -18,9 +18,8 @@ $(eval $(call gb_ExternalProject_register_targets,libvisio,\
$(eval $(call gb_ExternalProject_use_externals,libvisio,\
boost_headers \
icu \
- wpd \
- wpg \
libxml2 \
+ revenge \
zlib \
))
@@ -32,14 +31,14 @@ $(call gb_ExternalProject_get_state_target,libvisio,build) :
--enable-static \
--disable-shared \
--without-docs \
+ --disable-tools \
--disable-debug \
--disable-werror \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
CXXFLAGS="$(if $(SYSTEM_BOOST),$(BOOST_CPPFLAGS),-I$(call gb_UnpackedTarball_get_dir,boost) -I$(BUILDDIR)/config_$(gb_Side)) \
$(if $(SYSTEM_LIBXML),,-I$(call gb_UnpackedTarball_get_dir,xml2)/include)" \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && (cd $(EXTERNAL_WORKDIR)/src/lib && \
- $(if $(VERBOSE)$(verbose),V=1) \
- $(MAKE)) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libvisio/UnpackedTarball_libvisio.mk b/external/libvisio/UnpackedTarball_libvisio.mk
index 4680d78346b5..e4c0561f72f8 100644
--- a/external/libvisio/UnpackedTarball_libvisio.mk
+++ b/external/libvisio/UnpackedTarball_libvisio.mk
@@ -11,10 +11,4 @@ $(eval $(call gb_UnpackedTarball_UnpackedTarball,libvisio))
$(eval $(call gb_UnpackedTarball_set_tarball,libvisio,$(VISIO_TARBALL)))
-$(eval $(call gb_UnpackedTarball_set_patchlevel,libvisio,1))
-
-$(eval $(call gb_UnpackedTarball_add_patches,libvisio,\
- external/libvisio/0001-fdo-70480-do-not-crash-reading-malformed-zip.patch \
-))
-
# vim: set noet sw=4 ts=4:
diff --git a/external/libwpd/ExternalProject_libwpd.mk b/external/libwpd/ExternalProject_libwpd.mk
index 4d65938d403b..88b771580d80 100644
--- a/external/libwpd/ExternalProject_libwpd.mk
+++ b/external/libwpd/ExternalProject_libwpd.mk
@@ -15,20 +15,25 @@ $(eval $(call gb_ExternalProject_register_targets,libwpd,\
build \
))
+$(eval $(call gb_ExternalProject_use_externals,libwpd,\
+ revenge \
+))
+
$(call gb_ExternalProject_get_state_target,libwpd,build) :
$(call gb_ExternalProject_run,build,\
- $(if $(filter TRUE,$(DISABLE_DYNLOADING)),CFLAGS="$(CFLAGS) $(gb_VISIBILITY_FLAGS) $(gb_COMPILEROPTFLAGS)" CXXFLAGS="$(CXXFLAGS) $(gb_VISIBILITY_FLAGS) $(gb_COMPILEROPTFLAGS)") \
- ./configure \
+ export PKG_CONFIG="" \
+ && ./configure \
--with-pic \
--enable-static \
--disable-shared \
- --without-stream \
--without-docs \
+ --disable-tools \
--disable-debug \
$(if $(filter MACOSX,$(OS)),--disable-werror) \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
+ $(if $(filter TRUE,$(DISABLE_DYNLOADING)),CFLAGS="$(CFLAGS) $(gb_VISIBILITY_FLAGS) $(gb_COMPILEROPTFLAGS)" CXXFLAGS="$(CXXFLAGS) $(gb_VISIBILITY_FLAGS) $(gb_COMPILEROPTFLAGS)") \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && $(if $(VERBOSE)$(verbose),V=1) \
- $(MAKE) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libwpg/ExternalProject_libwpg.mk b/external/libwpg/ExternalProject_libwpg.mk
index e8fafe709ebd..804a989f4598 100644
--- a/external/libwpg/ExternalProject_libwpg.mk
+++ b/external/libwpg/ExternalProject_libwpg.mk
@@ -16,6 +16,7 @@ $(eval $(call gb_ExternalProject_register_targets,libwpg,\
))
$(eval $(call gb_ExternalProject_use_externals,libwpg,\
+ revenge \
wpd \
))
@@ -27,12 +28,12 @@ $(call gb_ExternalProject_get_state_target,libwpg,build) :
--enable-static \
--disable-shared \
--without-docs \
+ --disable-tools \
--disable-debug \
--disable-werror \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && (cd $(EXTERNAL_WORKDIR)/src/lib && \
- $(if $(VERBOSE)$(verbose),V=1) \
- $(MAKE)) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
diff --git a/external/libwpg/UnpackedTarball_libwpg.mk b/external/libwpg/UnpackedTarball_libwpg.mk
index 7c76a958eaf5..03be2064afba 100644
--- a/external/libwpg/UnpackedTarball_libwpg.mk
+++ b/external/libwpg/UnpackedTarball_libwpg.mk
@@ -11,11 +11,4 @@ $(eval $(call gb_UnpackedTarball_UnpackedTarball,libwpg))
$(eval $(call gb_UnpackedTarball_set_tarball,libwpg,$(WPG_TARBALL)))
-# HACK to avoid the need to deliver the headers to $(OUTDIR). This
-# should be removed when libwpg is updated.
-$(eval $(call gb_UnpackedTarball_set_post_action,libwpg,\
- mkdir -p inc/libwpg && \
- cp -f src/lib/libwpg.h src/lib/WPGPaintInterface.h src/lib/WPGraphics.h inc/libwpg \
-))
-
# vim: set noet sw=4 ts=4:
diff --git a/external/libwps/ExternalProject_libwps.mk b/external/libwps/ExternalProject_libwps.mk
index a1b1bac9970f..f21c70d9933d 100644
--- a/external/libwps/ExternalProject_libwps.mk
+++ b/external/libwps/ExternalProject_libwps.mk
@@ -17,7 +17,7 @@ $(eval $(call gb_ExternalProject_register_targets,libwps,\
$(eval $(call gb_ExternalProject_use_externals,libwps,\
boost_headers \
- wpd \
+ revenge \
))
$(call gb_ExternalProject_get_state_target,libwps,build) :
@@ -28,13 +28,13 @@ $(call gb_ExternalProject_get_state_target,libwps,build) :
--enable-static \
--disable-shared \
--without-docs \
+ --disable-tools \
--disable-debug \
--disable-werror \
+ $(if $(VERBOSE)$(verbose),--disable-silent-rules,--enable-silent-rules) \
CXXFLAGS="$(if $(SYSTEM_BOOST),$(BOOST_CPPFLAGS),-I$(call gb_UnpackedTarball_get_dir,boost) -I$(BUILDDIR)/config_$(gb_Side))" \
$(if $(CROSS_COMPILING),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) \
- && (cd $(EXTERNAL_WORKDIR)/src/lib && \
- $(if $(VERBOSE)$(verbose),V=1) \
- $(MAKE)) \
+ && $(MAKE) \
)
# vim: set noet sw=4 ts=4:
--- a/inc/libodfgen/OdgGenerator.hxx
+++ b/inc/libodfgen/OdgGenerator.hxx
@@ -27,6 +27,7 @@
- #include <libwpd/libwpd.h>
- #include <libwpg/libwpg.h>
+
+ #include <librevenge/librevenge.h>
+#include "libodfgen-api.hxx"
#include "OdfDocumentHandler.hxx"
- class OdgGeneratorPrivate;
+ class OdfGenerator;
@@ -37,7 +38,7 @@ class OdgGeneratorPrivate;
* See @c libwpg library for documentation of the
* libwpg::WPGPaintInterface interface.
*/
--class OdgGenerator : public libwpg::WPGPaintInterface
-+class ODFGENAPI OdgGenerator : public libwpg::WPGPaintInterface
+-class OdgGenerator : public librevenge::RVNGDrawingInterface
++class ODFGENAPI OdgGenerator : public librevenge::RVNGDrawingInterface
{
public:
- OdgGenerator(OdfDocumentHandler *pHandler, const OdfStreamType streamType);
+ OdgGenerator();
@@ -37,7 +38,7 @@ class OdgGeneratorPrivate;
- * See @c libwpg library for documentation of the
- * libwpg::WPGPaintInterface interface.
+ * See @c librevenge library for documentation of the
+ * librevenge::WPGPaintInterface interface.
*/
diff --git a/inc/libodfgen/OdpGenerator.hxx b/inc/libodfgen/OdpGenerator.hxx
index 71f2562..c61f5ad 100644
--- a/inc/libodfgen/OdpGenerator.hxx
+++ b/inc/libodfgen/OdpGenerator.hxx
@@ -27,6 +27,7 @@
- #include <libetonyek/libetonyek.h>
+ #include <librevenge/librevenge.h>
+#include "libodfgen-api.hxx"
#include "OdfDocumentHandler.hxx"
- class OdpGeneratorPrivate;
+ class OdfGenerator;
@@ -37,7 +38,7 @@ class OdpGeneratorPrivate;
- * See @c libetonyek library for documentation of the
- * libetonyek::KEYPresentationInterface interface.
+ * See @c librevenge library for documentation of the
+ * librevenge::KEYPresentationInterface interface.
+ */
+-class OdpGenerator : public librevenge::RVNGPresentationInterface
++class ODFGENAPI OdpGenerator : public librevenge::RVNGPresentationInterface
+ {
+ public:
+ OdpGenerator();
+diff --git a/inc/libodfgen/OdsGenerator.hxx b/inc/libodfgen/OdsGenerator.hxx
+index f88c207..09e1b18 100644
+--- a/inc/libodfgen/OdsGenerator.hxx
++++ b/inc/libodfgen/OdsGenerator.hxx
+@@ -29,6 +29,7 @@
+
+ #include <librevenge/librevenge.h>
+
++#include "libodfgen-api.hxx"
+ #include "OdfDocumentHandler.hxx"
+
+ class OdfGenerator;
+@@ -39,7 +40,7 @@ class OdsGeneratorPrivate;
+ * See @c libdocumentinterface library for documentation of the librevenge::RVNGSpreadsheetInterface
+ * interface.
*/
--class OdpGenerator : public libetonyek::KEYPresentationInterface
-+class ODFGENAPI OdpGenerator : public libetonyek::KEYPresentationInterface
+-class OdsGenerator : public librevenge::RVNGSpreadsheetInterface
++class ODFGENAPI OdsGenerator : public librevenge::RVNGSpreadsheetInterface
{
public:
- OdpGenerator(OdfDocumentHandler *pHandler, const OdfStreamType streamType);
+ OdsGenerator();
diff --git a/inc/libodfgen/OdtGenerator.hxx b/inc/libodfgen/OdtGenerator.hxx
index 9c3ff88..e11778c 100644
--- a/inc/libodfgen/OdtGenerator.hxx
+++ b/inc/libodfgen/OdtGenerator.hxx
@@ -29,6 +29,7 @@
- #include <libwpd/libwpd.h>
+ #include <librevenge/librevenge.h>
+#include "libodfgen-api.hxx"
#include "OdfDocumentHandler.hxx"
- /** Handler for embedded objects.
+ class OdtGeneratorPrivate;
@@ -39,7 +40,7 @@ class OdfGenerator;
* See @c libwpd library for documentation of the ::WPXDocumentInterface
* interface.
*/
--class OdtGenerator : public WPXDocumentInterface
-+class ODFGENAPI OdtGenerator : public WPXDocumentInterface
+-class OdtGenerator : public librevenge::RVNGTextInterface
++class ODFGENAPI OdtGenerator : public librevenge::RVNGTextInterface
{
public:
- OdtGenerator(OdfDocumentHandler *pHandler, const OdfStreamType streamType);
+ OdtGenerator();
@@ -39,7 +40,7 @@ class OdfGenerator;
- * See @c libwpd library for documentation of the ::WPXDocumentInterface
+ * See @c librevenge library for documentation of the ::librevenge::RVNGTextInterface
* interface.
*/